@@ -139,9 +139,11 @@ int kdemain(int argc, char **argv)
 }
 
 ThumbnailProtocol::ThumbnailProtocol(const QByteArray &pool, const QByteArray &app)
-    : SlaveBase("thumbnail", pool, app)
+    : SlaveBase("thumbnail", pool, app),
+      m_iconSize(0),
+      m_maxFileSize(0)
 {
-    m_iconSize = 0;
+
 }
 
 ThumbnailProtocol::~ThumbnailProtocol()
@@ -280,14 +282,7 @@ void ThumbnailProtocol::get(const KUrl &url)
         }
     }
 
-    if (img.width() > m_width || img.height() > m_height) {
-        double imgRatio = (double)img.height() / (double)img.width();
-        if (imgRatio > (double)m_height / (double)m_width) {
-            img = img.scaled( int(qMax((double)m_height / imgRatio, 1.0)), m_height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        } else {
-            img = img.scaled(m_width, int(qMax((double)m_width * imgRatio, 1.0)), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        }
-    }
+    scaleDownImage(img, m_width, m_height);
 
 // ### FIXME
 #ifndef USE_KINSTANCE
@@ -499,6 +494,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
         const KConfigGroup globalConfig(KGlobal::config(), "PreviewSettings");
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
+        m_maxFileSize = globalConfig.readEntry("MaximumSize", 5 * 1024 * 1024); // 5 MByte default
     }
     
     const int tiles = 2; //Count of items shown on each dimension
@@ -572,6 +568,12 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
                 break; // Never show the same thumbnail twice
             }
 
+            if (dir.fileInfo().size() > m_maxFileSize) {
+                // don't create thumbnails for files that exceed
+                // the maximum set file size
+                continue;
+            }
+
             QImage subThumbnail;
             if (!createSubThumbnail(subThumbnail, dir.filePath(), segmentWidth, segmentHeight)) {
                 continue;
@@ -739,6 +741,8 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
             QString tempFileName;
             bool savedCorrectly = false;
             if (subCreator->create(filePath, cacheSize, cacheSize, thumbnail)) {
+                scaleDownImage(thumbnail, cacheSize, cacheSize);
+
                 // The thumbnail has been created successfully. Store the thumbnail
                 // to the cache for future access.
                 KTemporaryFile temp;
@@ -764,4 +768,16 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
     return true;
 }
 
+void ThumbnailProtocol::scaleDownImage(QImage& img, int maxWidth, int maxHeight)
+{
+    if (img.width() > maxWidth || img.height() > maxHeight) {
+        const double imgRatio = (double)img.height() / (double)img.width();
+        if (imgRatio > (double)maxHeight / (double)maxWidth) {
+            img = img.scaled( int(qMax((double)maxHeight / imgRatio, 1.0)), maxHeight, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        } else {
+            img = img.scaled(maxWidth, int(qMax((double)maxWidth * imgRatio, 1.0)), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        }
+    }
+}
+
 
