@@ -1,4 +1,5 @@
 /*
+ * Copyright 2008 Long Huynh Huu <long.upcase@googlemail.com>
  * Copyright 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
  * Copyright 2007 Casper Boemann <cbr@boemann.dk>
  *
@@ -21,7 +22,7 @@
 #define __OXYGEN_STYLE_HELPER_H
 
 #include "lib/helper.h"
-#include "tileset.h"
+#include "lib/tileset.h"
 
 class SlabCache {
 public:
@@ -64,12 +65,8 @@ public:
 
     TileSet *slitFocused(const QColor&);
 
-    TileSet *verticalScrollBar(const QColor&, int width, int offset, int size = 6);
-    TileSet *horizontalScrollBar(const QColor&, int width, int offset, int size = 6);
-
-    TileSet *progressBar(const QColor&, QRect rect, Qt::Orientation orient = Qt::Horizontal, int size = 6);
-
     TileSet *dockFrame(const QColor&, int size);
+    TileSet *scrollHole(const QColor&, Qt::Orientation orientation);
 
 protected:
     SlabCache* slabCache(const QColor&);
@@ -89,10 +86,8 @@ protected:
     QCache<quint64, TileSet> m_slopeCache;
     QCache<quint64, TileSet> m_grooveCache;
     QCache<quint64, TileSet> m_slitCache;
-    QCache<quint64, TileSet> m_verticalScrollBarCache;
-    QCache<quint64, TileSet> m_horizontalScrollBarCache;
-    QCache<quint64, TileSet> m_progressBarCache;
     QCache<quint64, TileSet> m_dockFrameCache;
+    QCache<quint64, TileSet> m_scrollHoleCache;
 };
 
 #endif // __OXYGEN_STYLE_HELPER_H
