@@ -51,7 +51,7 @@
 #include <QTabBar>
 
 #include "helper.h"
-#include "tileset.h"
+#include "lib/tileset.h"
 
 #define u_arrow -4,1, 2,1, -3,0, 1,0, -2,-1, 0,-1, -1,-2
 #define d_arrow -4,-2, 2,-2, -3,-1, 1,-1, -2,0, 0,0, -1,1
@@ -62,14 +62,6 @@
 
 class QTimer;
 
-class OWidget : public QWidget
-{
-    friend class OxygenStyle;
-public:
-    OWidget(QWidget *parent) : QWidget(parent) {}
-};
-
-
 class OxygenStyle : public KStyle
 {
     Q_OBJECT
@@ -109,7 +101,8 @@ public:
         Focus = 0x2,
         Hover = 0x4,
         Disabled = 0x8,
-        NoFill = 0x10
+        NoFill = 0x10,
+        SubtleShadow = 0x20
     };
     Q_DECLARE_FLAGS(StyleOptions, StyleOption)
 
@@ -161,6 +154,9 @@ protected:
                    const QStyleOptionTabV2 *tabOpt,
                    const bool reverseLayout) const;
 
+    void fillTab(QPainter *p, const QRect &r, const QColor &color, Qt::Orientation orientation,
+                 bool active, bool inverted) const;
+
     void renderWindowIcon(QPainter *p, const QRectF &r, int &type) const;
 
     void renderScrollBarHole(QPainter *p, const QRect &r, const QColor &color,
@@ -183,19 +179,12 @@ private:
     QPoint handleRTL(const QStyleOption* opt, const QPoint& pos) const;
     QRect handleRTL(const QStyleOption* opt, const QRect& subRect) const;
 
-    bool _animateProgressBar;
-    bool _drawToolBarItemSeparator;
-    bool _drawTriangularExpander;
-    bool _checkCheck;
-    enum {
-        MM_DARK = 0,
-        MM_SUBTLE = 1,
-        MM_STRONG = 2
-    } _menuHighlightMode;
+    // configuration
+    void loadConfiguration();
 
     // global colors
     OxygenStyleHelper &_helper;
-    KSharedConfigPtr _config;
+    KSharedConfigPtr _sharedConfig;
     KStatefulBrush _viewFocusBrush;
     KStatefulBrush _viewHoverBrush;
 
