@@ -43,6 +43,7 @@
 #include <kwindowsystem.h>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
+#include <KNotification>
 
 #include <QtCore/QDir>
 #include <QtGui/QTextDocument> // Qt::escape
@@ -401,7 +402,7 @@ int KWalletD::doTransactionOpen(const QString& appid, const QString& wallet, boo
 int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isPath, WId w,
                            bool modal, const QString& service) {
 	bool brandNew = false;
-
+	
 	QString thisApp;
 	if (appid.isEmpty()) {
 		thisApp = "KDE System";
@@ -413,7 +414,7 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 		return -1;
 	}
 
-	const QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+	QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
 	int rc = walletInfo.first;
 	if (rc == -1) {
 		if (_wallets.count() > 20) {
@@ -443,6 +444,32 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 				kpd->setButtonGuiItem(KDialog::Ok,KGuiItem( i18n( "&Open" ), "document-open"));
 				kpd->setCaption(i18n("KDE Wallet Service"));
 				kpd->setPixmap(KIcon("kwalletmanager").pixmap(KIconLoader::SizeHuge));
+				if (w != KWindowSystem::activeWindow() && w != 0L) {
+					// If the dialog is modal to a minimized window it might not be visible
+					// (but still blocking the calling application). Notify the user about
+					// the request to open the wallet.
+					KNotification *notification = new KNotification("needsPassword", kpd,
+					                                                KNotification::Persistent |
+					                                                KNotification::CloseWhenWidgetActivated);
+					QStringList actions(i18nc("Text of a button to ignore the open-wallet notification", "Ignore"));
+					if (appid.isEmpty()) {
+						notification->setText(i18n("<b>KDE</b> has requested to open a wallet (%1).",
+						                           Qt::escape(wallet)));
+						actions.append(i18nc("Text of a button for switching to the (unnamed) application "
+						                     "requesting a password", "Switch there"));
+					} else {
+						notification->setText(i18n("<b>%1</b> has requested to open a wallet (%2).",
+						                           Qt::escape(appid), Qt::escape(wallet)));
+						actions.append(i18nc("Text of a button for switching to the application requesting "
+						                     "a password", "Switch to %1", Qt::escape(appid)));
+					}
+					notification->setActions(actions);
+					connect(notification, SIGNAL(action1Activated()),
+					        notification, SLOT(close()));
+					connect(notification, SIGNAL(action2Activated()),
+					        this, SLOT(activatePasswordDialog()));
+					notification->sendEvent();
+				}
 				while (!b->isOpen()) {
 					setupDialog( kpd, w, appid, modal );
 					if (kpd->exec() == KDialog::Accepted) {
@@ -528,11 +555,28 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 			KToolInvocation::startServiceByDesktopName("kwalletmanager-kwalletd");
 		}
 	} else {
-		if (!_sessions.hasSession(appid, rc) && !isAuthorizedApp(appid, wallet, w)) {
+		// prematurely add a reference so that the wallet does not close while the
+		// authorization dialog is being shown.
+		walletInfo.second->ref();
+		bool isAuthorized = _sessions.hasSession(appid, rc) || isAuthorizedApp(appid, wallet, w);
+		// as the wallet might have been forcefully closed, find it again to make sure it's
+		// still available (isAuthorizedApp might show a dialog).
+		walletInfo = findWallet(wallet);
+		if (!isAuthorized) {
+			if (walletInfo.first != -1) {
+				walletInfo.second->deref();
+				// check if the wallet should be closed now.
+				internalClose(walletInfo.second, walletInfo.first, false);
+			}
 			return -1;
+		} else {
+			if (walletInfo.first != -1) {
+				_sessions.addSession(appid, service, rc);
+			} else {
+				// wallet was forcefully closed.
+				return -1;
+			}
 		}
-		_sessions.addSession(appid, service, rc);
-		_wallets.value(rc)->ref();
 	}
 
 	return rc;
@@ -1407,4 +1451,11 @@ void KWalletD::screenSaverChanged(bool s)
 		closeAllWallets();
 }
 
+void KWalletD::activatePasswordDialog()
+{
+	if (activeDialog) {
+		KWindowSystem::forceActiveWindow(activeDialog->winId());
+	}
+}
+
 #include "kwalletd.moc"
