@@ -28,12 +28,16 @@ namespace Nepomuk {
     class Storage : public Service
     {
         Q_OBJECT
-//        Q_CLASSINFO( "D-Bus Interface", "org.kde.nepomuk.Storage" )
+        Q_CLASSINFO( "D-Bus Interface", "org.kde.nepomuk.Storage" )
 
     public:
         Storage( QObject* parent, const QList<QVariant>& args = QList<QVariant>() );
         ~Storage();
 
+    public Q_SLOTS:
+        Q_SCRIPTABLE void optimize( const QString& repo );
+        Q_SCRIPTABLE QString usedSopranoBackend() const;
+
     private Q_SLOTS:
         void slotNepomukCoreInitialized( bool success );
 
