@@ -37,13 +37,6 @@
 #include <kconfiggroup.h>
 #include <kdesktopfile.h>
 
-#if defined(_MSC_VER)
-#define MY_CAST(a) a
-#else
-// mingw needs char cast
-#define MY_CAST(a) (CHAR *)(a)
-#endif
-
 /*
     add correct prefix for win32 filesystem functions
     described in msdn, but taken from Qt's qfsfileeninge_win.cpp
@@ -52,7 +45,8 @@ static QString longFileName(const QString &path)
 {
     QString absPath = QDir::convertSeparators(path);
     QString prefix = QLatin1String("\\\\?\\");
-    if (path.startsWith("//") || path.startsWith("\\\\")) {
+    if (path.startsWith(QLatin1String("//")) ||
+        path.startsWith(QLatin1String("\\\\"))) {
         prefix = QLatin1String("\\\\?\\UNC\\");
         absPath.remove(0, 2);
     }
@@ -71,13 +65,7 @@ bool LinkFile::read()
     IPersistFile*  ppf     = NULL;
     bool           bResult = false;
 
-#   if !defined(UNICODE)
-        WCHAR wsz[MAX_PATH];
-        if (0 == MultiByteToWideChar(CP_ACP, 0, MY_CAST(szShortcutFile), -1, wsz, MAX_PATH) )
-            goto cleanup;
-#   else
-        LPCWSTR wsz = szShortcutFile;
-#   endif
+    LPCWSTR wsz = szShortcutFile;
 
     if (FAILED( CoCreateInstance(CLSID_ShellLink, NULL, CLSCTX_INPROC_SERVER, IID_IShellLink, (void **) &psl) ))
         goto cleanup;
@@ -88,19 +76,19 @@ bool LinkFile::read()
     if (FAILED( ppf->Load(wsz, STGM_READ) ))
         goto cleanup;
 
-    if (NOERROR != psl->GetPath(MY_CAST(szTarget), MAX_PATH, NULL, 0) )
+    if (NOERROR != psl->GetPath(szTarget, MAX_PATH, NULL, 0) )
         goto cleanup;
     m_execPath = QString::fromUtf16((const ushort*)szTarget);
 
-    if (NOERROR != psl->GetWorkingDirectory(MY_CAST(szWorkingDir), MAX_PATH) )
+    if (NOERROR != psl->GetWorkingDirectory(szWorkingDir, MAX_PATH) )
         goto cleanup;
     m_workingDir = QString::fromUtf16((const ushort*)szWorkingDir);
 
-    if (NOERROR != psl->GetDescription(MY_CAST(szDescription), MAX_PATH) )
+    if (NOERROR != psl->GetDescription(szDescription, MAX_PATH) )
         goto cleanup;
     m_description = QString::fromUtf16((const ushort*)szDescription);
 
-    if (NOERROR != psl->GetArguments(MY_CAST(szArguments), MAX_PATH) )
+    if (NOERROR != psl->GetArguments(szArguments, MAX_PATH) )
         goto cleanup;
     m_arguments = QString::fromUtf16((const ushort*)szArguments).split(QLatin1Char(' '), QString::SkipEmptyParts);
 
@@ -187,7 +175,7 @@ bool LinkFile::remove()
     return ret;
 }
 
-bool LinkFile::exists()
+bool LinkFile::exists() const
 {
     return QFile::exists(m_linkPath);
 }
@@ -199,10 +187,10 @@ bool LinkFiles::scan(QList <LinkFile> &files, const QString &path)
     bool has_err = false;
     if (aDir.exists())//QDir::NoDotAndDotDot
     {
-        QFileInfoList entries = aDir.entryInfoList(QDir::NoDotAndDotDot | 
-        QDir::Dirs | QDir::Files);
-        int count = entries.size();
-        foreach(QFileInfo entryInfo, entries)
+        const QFileInfoList entries = aDir.entryInfoList(QDir::NoDotAndDotDot | 
+                                                         QDir::Dirs |
+                                                         QDir::Files);
+        foreach(const QFileInfo &entryInfo, entries)
         {
             QString _path = entryInfo.absoluteFilePath();
             if (entryInfo.isDir())
@@ -211,8 +199,8 @@ bool LinkFiles::scan(QList <LinkFile> &files, const QString &path)
             }
             else
             {
-                if (_path.toLower().endsWith(".lnk"))
-                    files.append(LinkFile("",_path,"",""));
+                if (_path.toLower().endsWith(QLatin1String(".lnk")))
+                    files.append(LinkFile(QString(),_path,QString(),QString()));
             }
         }
     }
@@ -242,7 +230,7 @@ bool LinkFiles::cleanup(QList <LinkFile> &newFiles, QList <LinkFile> &oldFiles)
     {
         QString oldPath = QDir::fromNativeSeparators ( oldFile.linkPath().toLower() );
         bool found = false;
-        foreach(LinkFile newFile, newFiles)
+        foreach(const LinkFile &newFile, newFiles)
         {
             QString newPath = QDir::fromNativeSeparators ( newFile.linkPath().toLower());
             if (newPath == oldPath) 
